==> haskell-hspec-smallcheck-0.5.2-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-ES49GzCrare8EInNaQWKXJ
key: hspec-smallcheck-0.5.2-ES49GzCrare8EInNaQWKXJ
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: e7d848ec605bdd993bcbcad88d181f3d
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-ES49GzCrare8EInNaQWKXJ
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    hspec-core-2.7.0-DBpMwnVZJPDBYljRVbjI2A
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.2-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-3GJoKjxYaIc7NlRn9se6uN
key: hspec-smallcheck-0.5.2-3GJoKjxYaIc7NlRn9se6uN
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: 0e1cec68cc3f394c242cc8b6d8873fa9
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-3GJoKjxYaIc7NlRn9se6uN
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    hspec-core-2.7.1-3vaun58D2Am3OgsdQgwHyu
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
